@@ -46,7 +46,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.61_02'; # TRIAL VERSION
+our $VERSION = '1.61_03'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -75,6 +75,7 @@ our $VERSION = '1.61_02'; # TRIAL VERSION
     FTfunds
     Finanzpartner
     Fondsweb
+    Fool
     GoldMoney
     GoogleWeb
     HU
@@ -92,6 +93,7 @@ our $VERSION = '1.61_02'; # TRIAL VERSION
     SEB
     SIX
     Sinvestor
+    StockData
     Stooq
     TesouroDireto
     Tiaacref
@@ -1692,6 +1694,7 @@ http://www.gnucash.org/
   Finance::Quote::FTfunds,
   Finance::Quote::Finanzpartner,
   Finance::Quote::Fondsweb,
+  Finance::Quote::Fool,
   Finance::Quote::GoldMoney,
   Finance::Quote::GoogleWeb,
   Finance::Quote::HU,
@@ -1708,6 +1711,8 @@ http://www.gnucash.org/
   Finance::Quote::Oslobors,
   Finance::Quote::SEB,
   Finance::Quote::SIX,
+  Finance::Quote::StockData,
+  Finance::Quote::Stooq,
   Finance::Quote::TSP,
   Finance::Quote::TMX,
   Finance::Quote::Tiaacref,
